# -*- coding: utf-8 -*-
from SOAPpy import WSDL, faultType
from django.conf import settings
from logging import getLogger
logger = getLogger('coop')

from django.core.exceptions import ImproperlyConfigured

try:
    sympa_soap = settings.SYMPA_SOAP
    try:
        _server = WSDL.Proxy(sympa_soap['WSDL'])
    except Exception, e:
        logger.warning(u"Cannot find find Sympa server - %s" % e)
except ImportError:
    raise ImproperlyConfigured("coop.mailing is installed but we need SYMPA_SOAP settings.")


def lists():
    try:
        return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
                                                    sympa_soap['PASSWORD'],
                                                    'USER_EMAIL=' + sympa_soap['OWNER'],
                                                    'lists'
                                                    )
    except faultType, e:
        return e.faultstring


def info(name):
    try:
        return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
                                                    sympa_soap['PASSWORD'],
                                                    'USER_EMAIL=' + sympa_soap['OWNER'],
                                                    'info',
                                                    (name,)
                                                    )
    except faultType, e:
        return e.faultstring


def exists(name):
    list_info = info(name)
    if list_info == 'Unknown list':
        return False
    else:
        return list_info


def create_list(name, subject, template, description, topics=u'topics'):
    try:
        return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
                                                    sympa_soap['PASSWORD'],
                                                    'USER_EMAIL=' + sympa_soap['OWNER'],
                                                    'createList',
                                                    (name, subject, template, description, topics)
                                                    )
    except faultType, e:
        return e.faultstring


def close_list(name):
    try:
        return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
                                                    sympa_soap['PASSWORD'],
                                                    'USER_EMAIL=' + sympa_soap['OWNER'],
                                                    'closeList',
                                                    (name,)
                                                    )
    except faultType, e:
        return e.faultstring



from django.contrib import admin
from preferences.admin import PreferencesAdmin
from coop.utils.autocomplete_admin import FkAutocompleteAdmin, InlineAutocompleteAdmin


class SitePrefsAdmin(PreferencesAdmin, FkAutocompleteAdmin):
    related_search_fields = {'main_organization': ('title', 'subtitle', 'acronym'), }




from django.conf import settings
import agenda_settings


class AppSettings(object):
    SETTINGS_MODULE = None

    def __init__(self, base_settings_module, global_override):

        # update this dict from global settings (but only for ALL_CAPS settings)
        for setting in dir(base_settings_module):
            if setting == setting.upper():
                setattr(self, setting, getattr(base_settings_module, setting))

        if hasattr(settings, global_override):
            self.SETTINGS_MODULE = getattr(settings, global_override)
            try:
                mod = __import__(self.SETTINGS_MODULE, {}, {}, [''])
            except ImportError, e:
                raise ImportError(
                    "Could not import settings '%s' (Is it on sys.path? Does it have syntax errors?): %s" % (self.SETTINGS_MODULE, e)
                )

            for setting in dir(mod):
                if setting == setting.upper():
                    setattr(self, setting, getattr(mod, setting))

    def get_all_members(self):
        return dir(self)

settings = AppSettings(agenda_settings, 'AGENDA_SETTINGS_MODULE')


# -*- coding:utf-8 -*-
# Create your views here.

from django.http import HttpResponse
from soap import info as soap_info, lists


def list(request, name):
    """
    :name MailingList name
    """
    # TODO il faut contruite la liste a partir de la 
    return HttpResponse('clo claude.huchet@quinode.fr')



# # -*- coding:utf-8 -*-

from django.shortcuts import render_to_response
from coop_local.models import Organization, OrganizationCategory, Engagement, Role
from django.template import RequestContext
from django.shortcuts import render_to_response, get_object_or_404
from coop.org.forms import OrganizationForm, OrganizationCategoryForm
from django.contrib.auth.decorators import login_required
from logging import getLogger
from django.core.exceptions import ValidationError, PermissionDenied
from djaloha import utils as djaloha_utils
from django.contrib import messages
from django.utils.translation import ugettext as _
from django.http import HttpResponse, Http404, HttpResponseRedirect, HttpResponseForbidden
import coop_bar
from coop_cms.views import coop_bar_aloha_js


def org_category_detail(request, slug):
    cat = get_object_or_404(OrganizationCategory, slug=slug)
    org_list = Organization.objects.filter(category=cat)
    context = {'org_category': cat}
    context['org_list'] = org_list
    return render_to_response('org/org_category.html', context, RequestContext(request))


def org_detail(request, slug):
    context = {'editable': True}
    org = get_object_or_404(Organization, slug=slug)
    context['organization'] = org
    context['adresses'] = org.located.all()
    context['engagements'] = Engagement.objects.filter(organization=org)
    return render_to_response('org/org_detail.html', context, RequestContext(request))


@login_required
def org_edit(request, slug):
    logger = getLogger('default')
    organization = get_object_or_404(Organization, slug=slug)  # model
    if not request.user.has_perm('can_edit_org', organization):  # model
        raise PermissionDenied

    if request.method == "POST":
        form = OrganizationForm(request.POST, request.FILES, instance=organization)
        forms_args = djaloha_utils.extract_forms_args(request.POST)
        djaloha_forms = djaloha_utils.make_forms(forms_args, request.POST)
        if form.is_valid() and all([f.is_valid() for f in djaloha_forms]):
            logger.error('formulaire valide')
            organization = form.save()
            # if organization.temp_logo:
            #     organization.logo = organization.temp_logo
            #     organization.temp_logo = ''
            #     organization.save()
            if djaloha_forms:
                [f.save() for f in djaloha_forms]
            messages.success(request, _(u'Your changes have been saved properly'))

            return HttpResponseRedirect(organization.get_absolute_url())
        else:

            # import pdb
            # pdb.set_trace()
            for f in form.errors.keys():
                logger.error(u'FORM ERROR | ' + unicode(f) + u' : ' + unicode(form.errors[f][0]))
            messages.error(request, _(u"An error has occured."))

    else:
        from coop_bar.urls import bar
        if "pageSlide" not in bar.get_footer(request, RequestContext(request)):
            bar.register_footer(coop_bar_aloha_js)
        form = OrganizationForm(instance=organization)

    context_dict = {
        'form': form,
        'editable': True,
        'edit_mode': True,
        'title': organization.title,
        'organization': organization,
    }

    return render_to_response(
        'org/org_detail.html',
        context_dict,
        context_instance=RequestContext(request)
    )


@login_required
def org_category_edit(request, slug):
    logger = getLogger('default')
    org_category = get_object_or_404(OrganizationCategory, slug=slug)  # model
    if not request.user.has_perm('can_edit_org_category', org_category):  # model
        raise PermissionDenied

    if request.method == "POST":
        form = OrganizationCategoryForm(request.POST, request.FILES, instance=org_category)
        forms_args = djaloha_utils.extract_forms_args(request.POST)
        djaloha_forms = djaloha_utils.make_forms(forms_args, request.POST)
        if form.is_valid() and all([f.is_valid() for f in djaloha_forms]):
            logger.error('formulaire valide')
            org_category = form.save()
            if djaloha_forms:
                [f.save() for f in djaloha_forms]
            messages.success(request, _(u'Your changes have been saved properly'))
            return HttpResponseRedirect(org_category.get_absolute_url())
        else:
            for f in form.errors.keys():
                logger.error(u'FORM ERROR | ' + unicode(f) + u' : ' + unicode(form.errors[f][0]))
            messages.error(request, _(u"An error has occured."))
    else:
        from coop_bar.urls import bar
        if "pageSlide" not in bar.get_footer(request, RequestContext(request)):
            bar.register_footer(coop_bar_aloha_js)
        form = OrganizationCategoryForm(instance=org_category)

    context_dict = {
        'form': form,
        'editable': True,
        'edit_mode': True,
        'title': org_category.label,  # ?
        'org_category': org_category,
    }

    return render_to_response(
        'org/org_category.html',
        context_dict,
        context_instance=RequestContext(request)
    )




@login_required
def org_edit_cancel(request, slug):
    """if cancel_edit, delete the preview image"""
    organization = get_object_or_404(Organization, slug=slug)
    # if organization.temp_logo:
    #     organization.temp_logo = ''
    #     organization.save()
    return HttpResponseRedirect(organization.get_absolute_url())


@login_required
def org_category_edit_cancel(request, slug):
    org_category = get_object_or_404(OrganizationCategory, slug=slug)
    return HttpResponseRedirect(org_category.get_absolute_url())


def org_list(request):
    context = {}
    context['org_list'] = Organization.objects.filter(active=True)
    return render_to_response('org/org_list.html', context, RequestContext(request))


def role_detail(request, slug):
    context = {}
    role = Role.objects.get(slug=slug)
    context['object'] = role
    context['engagements'] = Engagement.objects.filter(role=role).select_related('person').order_by('person__last_name')
    return render_to_response('org/role_detail.html', context, RequestContext(request))


def global_map(request):
    context = {}
    context['initiatives'] = Organization.objects.filter(active=True)
    return render_to_response('org/org_global_map.html',
                              context, RequestContext(request))

def leaflet(request):
    context = {}
    context['org_list'] = Organization.objects.filter(active=True)
    return render_to_response('org/org_carto.html', context, RequestContext(request))



from django.conf.urls.defaults import *

from coop.agenda import views


urlpatterns = patterns('coop.agenda.views',
    #url(r'^(?:calendar/)?$',
    url(r'^agenda/?$',
        'agenda_by_name',
        name='agenda-default'),

    url(r'^agenda/(?P<slug>[\w-]+)/$',
        'agenda_by_category',
        # 'agenda_by_name',
        name='agenda-default'),

    url(r'^agenda/category/(?P<slug>[\w-]+)/$',
        'event_category_view',
        name='agenda-event-category'),

    url(r'^agenda/(?P<year>\d{4})/$',
        'year_view',
        name='agenda-yearly-view'),

    url(r'^agenda/(\d{4})/(0?[1-9]|1[012])/$',
        'month_view',
        name='agenda-monthly-view'),

    url(r'^agenda/(\d{4})/(0?[1-9]|1[012])/([0-3]?\d)/$',
        'day_view',
        name='agenda-daily-view'),

    url(r'^evenements/$', 'event_listing',
        name='agenda-events'),

    url(r'^evenements/add/$',
        'add_event',
        name='agenda-add-event'),

    url(r'^evenements/(\d+)/$',
        'event_view',
        name='agenda-event'),

    url(r'^evenements/mini/(\d+)/$',
        'event_minimal_view',
        name='event-minimal-view'),  # CBV !!!

    url(r'^evenements/(\d+)/(\d+)/$',
        'occurrence_view',
        name='agenda-occurrence'),
)



# -*- coding:utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse
from django.conf import settings
import rdflib


if 'coop_tag' in settings.INSTALLED_APPS:
    from coop_tag.models import TagBase, GenericTaggedItemBase, TaggedItemBase
    from coop.models import URIModel
    # in coop_settings, TAGGER_TAG_MODEL = 'coop_local.Tag'

    class CoopTaggedItem(GenericTaggedItemBase, TaggedItemBase):
        #tag = models.ForeignKey('coop_local.Tag', related_name="%(app_label)s_%(class)s_taggeditem_items")

        class Meta:
            verbose_name = _(u'tagged item')
            verbose_name_plural = _(u'tagged items')
            abstract = True
            app_label = "coop_local"

    class CoopTag(TagBase, URIModel):
        # Fields name and slug are defined in TagBase

        language = models.CharField(_(u'language'), max_length=10, default='fr')
        person = models.ForeignKey('coop_local.Person', blank=True, null=True, verbose_name=_(u'person'), editable=False)
        person_uri = models.CharField(_(u'person URI'), blank=True, max_length=250, editable=False)

        # Thesaurus link
        concept_uri = models.CharField(_(u'Concept URI'), blank=True, max_length=250, editable=False)

        # Tags have a common uri domain
        domain_name = 'data.economie-solidaire.fr'

        @property
        def uri_id(self):
            return self.slug

        def label(self):
            return self.name

        def get_absolute_url(self):
            return reverse('tag_detail', args=[self.slug])

        class Meta:
            verbose_name = _(u'tag')
            verbose_name_plural = _(u'tags')
            abstract = True
            app_label = "coop_local"

        # RDDF stuff
        rdf_type = settings.NS.skosxl.Label
        base_mapping = [
            ('single_mapping', (settings.NS.dct.created, 'created'), 'single_reverse'),
            ('single_mapping', (settings.NS.dct.modified, 'modified'), 'single_reverse'),
            ('single_mapping', (settings.NS.skosxl.literalForm, 'name', None, 'fr'), 'single_reverse'),
            ('single_mapping', (settings.NS.rdfs.label, 'name', None, 'fr'), 'single_reverse'),
            ('single_mapping', (settings.NS.foaf.made, 'person_uri'), 'single_reverse'),
            ('single_mapping', (settings.NS.ess.labelFor, 'concept_uri'), 'single_reverse'),

            ('scheme_mapping', (settings.NS.skos.inScheme, ''), 'scheme_mapping_reverse'),
            ('broader_mapping', (settings.NS.ess.broaderLabel, ''), 'broader_mapping_reverse'),
       ]

        def scheme_mapping(self, rdfPred, djF, datatype=None, lang=None):
            try:
                m = models.get_model('coop_cms', 'navnode')
                nodes = m.objects.filter(object_id=self.id)
            except m.DoesNotExist:
                return []
            res = []
            for node in nodes:
                if  not node.tree.name == 'default':
                    res.append((rdflib.term.URIRef(self.uri), rdfPred, rdflib.term.URIRef(node.tree.uri)))
            return res

        #TODO to be TESTED..... comment ca marche les NavNode, NavTree....
        def scheme_mapping_reverse(self, g, rdfPred, djF, datatype=None, lang=None):
            schemes = list(g.objects(rdflib.term.URIRef(self.uri), rdfPred))
            nodes = models.get_model('coop_cms', 'navnode').objects.filter(object_id=self.id)
            # Un tag peut appartenir a plusieurs schemes
            mNavtree = models.get_model('coop_local', 'Navtree')
            for scheme in schemes:
                sch = mNavtree.objects.get(uri=scheme.toPython())
                for node in nodes:
                    if node.tree.id == sch.id:
                        node.tree = sch
                        node.save()


        def broader_mapping(self, rdfPred, djF, datatype=None, lang=None):
            try:
                m = models.get_model('coop_cms', 'navnode')
                nodes = m.objects.filter(object_id=self.id)
            except m.DoesNotExist:
                return []
            res = []
            for node in nodes:
                try:
                    node_parent = m.objects.get(id=node.parent.id)
                except (m.DoesNotExist, AttributeError):
                    node_parent = None

                if not node_parent == None and  node_parent.content_type.name == 'tag':
                    mTag = models.get_model('coop_local', 'tag')
                    tag_parent = mTag.objects.get(id=node_parent.object_id)
                    res.append((rdflib.term.URIRef(self.uri), rdfPred, rdflib.term.URIRef(tag_parent.uri)))
            return res



        def broader_mapping_reverse(self, g, rdfPred, djF, datatype=None, lang=None):
            pass












# -*- coding:utf-8 -*-
from django.contrib import admin
from django.conf.urls.defaults import patterns, include, url
from django.conf import settings

# # https://code.djangoproject.com/ticket/10405#comment:11
# from django.db.models.loading import cache as model_cache
# if not model_cache.loaded:
#     model_cache.get_models()

admin.autodiscover()


# Add you own URLs here
urlpatterns = []

# urlpatterns += patterns('',
#    url(r'^$', 'coop_local.views.home', name="home"),
#    url(r'^org/$', 'coop_local.views.org_list', name="org_list"), #view coop

# )


from coop.default_project_urls import urlpatterns as default_project_urls
urlpatterns += default_project_urls


if 'haystack' in settings.INSTALLED_APPS:
    # minimal version
    from haystack.views import search_view_factory, SearchView
    urlpatterns += patterns('haystack.views',
        url(r'^search/$', search_view_factory(
            view_class=SearchView,
            template='search/search.html',
            load_all=False
        ), name='haystack_search'),
    )




# -*- coding:utf-8 -*-

from django.contrib import admin
from django.conf import settings
from tinymce.widgets import AdminTinyMCE
from django import forms
from sorl.thumbnail.admin import AdminImageMixin
from coop.utils.autocomplete_admin import FkAutocompleteAdmin, NoLookupsFkAutocompleteAdmin

if "coop.agenda" in settings.INSTALLED_APPS:
    from coop.agenda.admin import DatedInline


if "coop_cms" in settings.INSTALLED_APPS:

    from coop_cms.admin import NavTreeAdmin, ArticleAdmin
    from coop_cms.settings import get_article_class, get_navTree_class
    from coop_cms.forms import ArticleAdminForm

    # -- We need to customize coop-cms NavtreeAdmin

    class MyNavTreeAdmin(NavTreeAdmin):
        change_form_template = 'admin/navtree_change_form.html'

    navtree_model = get_navTree_class()
    admin.site.unregister(navtree_model)
    admin.site.register(navtree_model, MyNavTreeAdmin)

    # -- We need to customize coop-cms ArticleAdmin

    class CoopArticleForm(ArticleAdminForm):
        content = forms.CharField(widget=AdminTinyMCE(attrs={'cols': 80, 'rows': 60}), required=False)


        # def __init__(self, *args, **kwargs):
        #     from django.forms.widgets import HiddenInput
        #     super(CoopArticleForm, self).__init__(*args, **kwargs)
        #     self.fields['remote_organization_uri'].widget = HiddenInput()
        #     self.fields['remote_person_uri'].widget = HiddenInput()


    class CoopArticleAdmin(ArticleAdmin, NoLookupsFkAutocompleteAdmin, AdminImageMixin):
        form = CoopArticleForm
        change_form_template = 'admintools_bootstrap/tabbed_change_form.html'
        change_list_template = 'admin/article_change_list.html'
        list_filter = ['category']
        search_fields = ['title', 'summary', 'content']
        ordering = ['-created']

        list_display = ['logo_list_display', 'title', 'publication', 'headline', 'isSection', 'category']
        list_editable = ['publication', 'isSection', 'headline', 'category']
        list_display_links = ['title']

        readonly_fields = []
        fieldsets = (
            #(_('Navigation'), {'fields': ('navigation_parent',)}),
            ('Edition', {'fields': ('title', 'logo', 'content', 
                                    'organization', 'remote_organization_label', 'remote_organization_uri',
                                    'person', 'remote_person_label', 'remote_person_uri')}),
            ('Options', {'fields': ('summary', 'category', 'template', 'is_homepage', 'in_newsletter', 'isSection')}),
        )
        related_search_fields = {'organization': ('title', 'subtitle', 'description'), 
                                 'person': ('first_name', 'last_name',), }

        if "coop.agenda" in settings.INSTALLED_APPS:
            inlines = [DatedInline]




# -*- coding:utf-8 -*-

from django.conf import settings
import sys

# Here you can override any settings from coop default settings files
# See :
# - coop/default_project_settings.py
# - coop/db_settings.py

SITE_AUTHOR = 'Organisme'
SITE_TITLE = 'Demo Django-coop'
# DEFAULT_URI_DOMAIN = '{{ domain }}' useless use Site.objects.get_current().domain instead

# let this setting to False in production, except for urgent debugging
DEBUG = False

# Force DEBUG setting if we're developing locally or testing
if 'runserver' in sys.argv or 'test' in sys.argv:
    DEBUG = True

TEMPLATE_DEBUG = DEBUG

ADMINS = (
    ('Administrateur', 'web@quinode.fr'),
)

MANAGERS = ADMINS
SEND_BROKEN_LINK_EMAILS = True
# INTERNAL_IPS = ('127.0.0.1', '92.243.30.98')

SUBHUB_MAINTENANCE_AUTO = False    # set this value to True to automatically syncronize with agregator
PES_HOST = 'pes.domain.com'
THESAURUS_HOST = 'thess.domain.com'

# Need to be set to true, when domain stop moving,
# to keep history of renaming of uri
URI_FIXED = False  

INSTALLED_APPS = settings.INSTALLED_APPS + [
    # select your coop components
    'coop.tag',
    'coop.agenda',
    'coop.article',
    'coop.mailing',
    'coop.exchange',
    #'coop.webid',
    'coop_local',
     # coop optional modules
    'coop_geo',  # est obligatoirement APRES coop_local
]

# TODO: to be discuss this settings could be in default_project_setings.py
# file. To be check I knew more on how to configure sympa
SYMPA_SOAP = {
    'WSDL': 'http://sympa.{{ root_domain }}/sympa/wsdl',
    'APPNAME': 'djangoapp',
    'PASSWORD': 'test',
    'OWNER': ADMINS[0][1],
    'PARAMETER_SEPARATOR': '__SEP__',      # used for template
}



# -*- coding:utf-8 -*-
from django.db import models
from django_extensions.db import fields as exfields
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes import generic
from extended_choices import Choices
from django.core.exceptions import ValidationError
from coop.mailing import soap
from django.contrib.sites.models import Site
from django.conf import settings


# The sympa templates for list
# /home/sympa/default/create_list_template
# they MUST match the repositories name, this is the aim of the
# templateName property
DISPLAY = Choices(
    ('DISCUSSION_LIST', 1, _(u'discussion list')),
    ('HOSTLINE',   2,  _(u'hotline')),
    ('HTML_NEWS_LETTER',  3,  _(u'html news letter')),
    ('INTRANET_LIST', 4,  _(u'intranet list')),
    ('NEWS_LETTER', 5,  _(u'news letter')),
    ('PRIVATE_WORKING',     6,  _(u'private working')),
    ('PUBLIC_WEB_FORUM',   7,  _(u'public web forum')),
    ('NEWS_REMOTE_SOURCE', 8, _(u'diffusion list with remote source')),
)


class BaseMailingList(models.Model):
    name = models.CharField(_('name'), max_length=50, unique=True)
    email = models.EmailField(_('Newsletter email'), editable=False)
    # main_url = models.URLField(_('List URL'))

    # Specific field to run sympa
    subject = models.CharField(max_length=200)
    template = models.PositiveSmallIntegerField(_(u'template'),
                    choices=DISPLAY.CHOICES, default=DISPLAY.NEWS_REMOTE_SOURCE)
    description = models.TextField(blank=True)  # could contains html balises
    # A choisir dans une liste... qui parametre cette liste,est-t-elle modifiable?
    # ... et encore pleins de questions. C'est de la mecanique interne a sympa et cela
    # semble optionnel.... on peut peut etre s'en passer et le gerer par nos tags
    # topics = models.CharField(max_length=200, blank=True)

    def __str__(self):
        return self.name

    def __unicode__(self):
        return u"%s" % self.name

    # laliste sympa est deja cree
    def clean(self, *args, **kwargs):
        # TODO quant on aura ajouter les noms de domaines... il faudrait
        # surement modifier des choses
        if soap.exists(self.name):
            raise ValidationError(_(u"List %s exists. If you want to reopen it, please contact the sympa list administator" % self.name))
        if not self.email:
            self.email = "%s@%s" % (self.name, Site.objects.get_current())
        if self.template == 8:
            # subject = '%s%shttp://%s/sympa_remote_list/%s' % (self.subject, settings.SYMPA_SOAP['PARAMETER_SEPARATOR'], Site.objects.get_current(), self.name)
            subject = '%s%shttp://www.credis.org/tmp/test_list.txt' % (self.subject, settings.SYMPA_SOAP['PARAMETER_SEPARATOR'])
        else:
            subject = self.subject
        result = soap.create_list(self.name, subject, self.templateName, self.description)
        if not result == 1:
            raise ValidationError(_(u"Cannot add the list (sympa cannot create it): %s" % result))
        super(BaseMailingList, self).clean(*args, **kwargs)

    def full_clean(self, *args, **kwargs):
        return self.clean(*args, **kwargs)

    def save(self, *args, **kwargs):
        self.full_clean()
        super(BaseMailingList, self).save(*args, **kwargs)

    def delete(self):
        result = 1
        if soap.exists(self.name):
            result = soap.close_list(self.name)

        if result == 1 or result == 'list allready closed':
            super(BaseMailingList, self).delete()
        else:
            raise Exception(_(u"Cannot close the list : %s" % result))


    class Meta:
        verbose_name = _('mailing list')
        verbose_name_plural = _('mailing lists')
        abstract = True
        app_label = 'coop_local'

    @property
    def templateName(self):
        """ We have to retourn the orresponding repertory name
        Please check with sympa server directory /home/sympa/default/create_list_templates
        """
        if self.template == DISPLAY.DISCUSSION_LIST:
            return 'discussion_list'
        elif self.template == DISPLAY.HOSTLINE:
            return 'hotline'
        elif self.template == DISPLAY.HTML_NEWS_LETTER:
            return 'html-news-letter'
        elif self.template == DISPLAY.INTRANET_LIST:
            return 'intranet_list'
        elif self.template == DISPLAY.NEWS_LETTER:
            return 'news-letter'
        elif self.template == DISPLAY.PRIVATE_WORKING:
            return 'private_working_group'
        elif self.template == DISPLAY.PUBLIC_WEB_FORUM:
            return 'pulic_web_forum'
        elif self.template == DISPLAY.NEWS_REMOTE_SOURCE:
            return 'news-remote-source'
        else:
            return ''


# class Parameter(models.Model):
#     list = models.ForeignKey('coop_local.MailingList')
#     value = models.CharField(max_length=200)

#     def __str__(self):
#         return self.value

#     def __unicode__(self):
#         return u"%s" % self.value




class BaseSubscription(models.Model):
    mailing_list = models.ForeignKey('coop_local.MailingList',
                                        related_name='subs')
    created = exfields.CreationDateTimeField(_(u'created'), null=True)
    modified = exfields.ModificationDateTimeField(_(u'modified'), null=True)
    # subscription options (HTML, text ...)
    email = models.EmailField(_('subscribed email'), default='')

    # things which are suscribed
    content_type = models.ForeignKey(ContentType, blank=True, null=True)
    object_id = models.PositiveIntegerField()
    content_object = generic.GenericForeignKey('content_type', 'object_id')

    class Meta:
        verbose_name = _('mailing list subscription')
        verbose_name_plural = _('mailing list subscriptions')
        abstract = True
        app_label = 'coop_local'

    def __unicode__(self):
        return _(u'subscription to ') + unicode(self.mailing_list)



# -*- coding:utf-8 -*-

from coop_local.settings import PROJECT_NAME

DATABASES = {
    'default': {
        'ENGINE': 'django.contrib.gis.db.backends.postgis',  # Add 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
        'NAME': PROJECT_NAME,                      # Or path to database file if using sqlite3.
        'USER': 'admin',                      # Not used with sqlite3.
        'PASSWORD': '123456',                  # Not used with sqlite3.
   },
    'geofla_db': {
        'ENGINE': 'django.contrib.gis.db.backends.postgis',  # Add 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
        'NAME': PROJECT_NAME,                      # Or path to database file if using sqlite3.
        'USER': 'admin',                      # Not used with sqlite3.
        'PASSWORD': '123456',                  # Not used with sqlite3.
    },
}

# For redis
REDIS_PORT = 6379  # Please ask for a redis port to your administrator. Default value 6379, may already been used'

# # For django-rq, this mandatory to run rqworker command from manage.py
RQ_QUEUES = {
    'default': {
        'HOST': '127.0.0.1',
        'PORT': REDIS_PORT,
        'DB': 0,
    },
}


# Elastic search
HAYSTACK_CONNECTIONS = {
    'default': {
        'ENGINE': 'haystack_fr.backends.elasticsearch_backend.ElasticsearchSearchEngine',
        'URL': 'http://localhost:9200/',
        'INDEX_NAME': settings.PROJECT_NAME,
        # 'INCLUDE_SPELLING': True,   # not yet handled by ES
    },
}

